@@ -60,7 +60,6 @@ class ModeSplitter(BaseTool):
         from ..utils import doi,remove_outliers
         _X,_y = X[:],y[:] # copy the arrays
         indexes,peaks = _separate_by_modes(_X,_y)
-        print(peaks)
         self.n_segments = len( indexes )
         separated_xs = [
             _X[idxs].reshape(idxs.shape[0],_X.shape[1]) for idxs in indexes
@@ -90,7 +89,7 @@ class ModeSplitter(BaseTool):
                 datum_x[kls].append( _X[i] )
                 datum_y[kls].append( _y[i] )
             self.predictors = [
-                self.predict_fn( **self.predict_kwargs ).fit( list(separated_xs[_])+datum_x[_],list(separated_ys[_])+datum_y[_] ) for _ in range(len(indexes))
+                self.predict_fn( **self.predict_kwargs ).fit( list(separated_xs[_]),list(separated_ys[_]) ) for _ in range(len(indexes))
             ]
 
         return self
@@ -98,7 +97,13 @@ class ModeSplitter(BaseTool):
 
     def predict(self,x):
         if len(self.predictors) < 1:return self.split_fn.predict(x)
-        else: return [self.predictors[ idx ].predict( [x[idx]] )[0] for idx in self.split_fn.predict(x)]
+        else: return [ 
+                    (np.array([ 
+                                self.predictors[ idx ].predict( [x[idx]] )[0] 
+                                for jdx in range(self.n_segments)  
+                            ]) *probs)/probs.sum()
+                    for idx,probs in enumerate(self.split_fn.predict_proba(x)) 
+            ]
         
 
 
